@@ -2,93 +2,122 @@
 //
 // KTux - QCanvas based screensaver
 //
-// Copyright (c)  Martin R. Jones 1999
+// Copyright Martin R. Jones 1999 <mjones@kde.org>
 //
 
+#include "sprite.h"
+#include "spritepm.h"
+#include "spritemisc.h"
+#include "sprite.moc"
+
 #include <stdlib.h>
 #include <time.h>
-#include <qlabel.h>
-#include <qmessagebox.h>
-#include <qlayout.h>
-#include <qslider.h>
+
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QSlider>
+#include <QtGui/QPixmap>
+#include <QtCore/QTimerEvent>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QFrame>
+#include <QtGui/QHBoxLayout>
+
+#include <kconfiggroup.h>
+#include <KPushButton>
+#include <KMessageBox>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdebug.h>
-#include <kstdguiitem.h>
-#include <kbuttonbox.h>
-
-#include "spritepm.h"
-#include "spritemisc.h"
-#include "sprite.h"
-#include "sprite.moc"
-
+#include <KStandardGuiItem>
+#include <kguiitem.h>
+#include <krandom.h>
+#include <KDialogButtonBox>
 
 // libkscreensaver interface
-extern "C"
+class KSpriteSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char *kss_applicationName = "ktux";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "Tux Screen Saver" );
-    KDE_EXPORT const char *kss_version = "1.0.0";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "ktux", 0, ki18n( "Tux Screen Saver" ), "1.0.0", ki18n( "Tux Screen Saver" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new KSpriteSaver( id );
     }
 
-    KDE_EXPORT QDialog *kss_setup()
+    virtual QDialog* setup()
     {
         return new KSpriteSetup();
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KSpriteSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 //-----------------------------------------------------------------------------
 
 KSpriteSetup::KSpriteSetup( QWidget *parent, const char *name )
-  : QDialog( parent, name, TRUE )
+  : KDialog( parent )
 {
-    KGlobal::locale()->insertCatalogue("ktux");
+    setObjectName(name);
+    KGlobal::locale()->insertCatalog("ktux");
     saver = 0;
 
+    setButtons(Ok|Cancel|Help);
+    setDefaultButton(Ok);
+    setButtonText( Help, i18n( "A&bout" ) );
+    setModal(true);
+    showButtonSeparator(true);
+    QWidget *main = new QWidget(this);
+    setMainWidget(main);
+
     readSettings();
+    setWindowTitle(i18n("Setup KTux") );
 
-    setCaption(i18n("Setup KTux") );
-
-    QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
+    QVBoxLayout *tl = new QVBoxLayout(main);
+    tl->setSpacing(10);
+    tl->setMargin(10);
     QHBoxLayout *tl1 = new QHBoxLayout;
     tl->addLayout(tl1);
-    QVBoxLayout *tl11 = new QVBoxLayout(5);
+    QVBoxLayout *tl11 = new QVBoxLayout();
+    tl11->setSpacing( 5 );
     tl1->addLayout(tl11);
 
-    QLabel *label = new QLabel( i18n("Speed:"), this );
+    QLabel *label = new QLabel( i18n("Speed:"), main );
     label->setMinimumSize(label->sizeHint());
     tl11->addStretch(1);
     tl11->addWidget(label);
 
-    QSlider *sb = new QSlider(0, 100, 10, speed, QSlider::Horizontal, this );
+    QSlider *sb = new QSlider( Qt::Horizontal,main);
+    sb->setMinimum(0);
+    sb->setMaximum(100);
+    sb->setPageStep(10);
+    sb->setValue(speed);
     tl11->addWidget(sb);
     connect( sb, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
 
-    preview = new QWidget( this );
+    preview = new QWidget( main );
     preview->setFixedSize( 220, 170 );
-    preview->setBackgroundColor( black );
+
+    QPalette palette;
+    palette.setColor(preview->backgroundRole(), Qt::black);
+    preview->setPalette(palette);
+    preview->setAutoFillBackground(true);
     preview->show();    // otherwise saver does not get correct size
     saver = new KSpriteSaver( preview->winId() );
     tl1->addWidget(preview);
 
-    KButtonBox *bbox = new KButtonBox(this);
-    QButton *button = bbox->addButton( i18n("About"));
-    connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-    bbox->addStretch(1);
+    connect( this, SIGNAL( helpClicked() ), SLOT(slotAbout() ) );
 
-    button = bbox->addButton( KStdGuiItem::ok());
-    connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
+    connect( this, SIGNAL( okClicked() ), SLOT( slotOkPressed() ) );
 
-    button = bbox->addButton(KStdGuiItem::cancel());
-    connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-    bbox->layout();
-    tl->addWidget(bbox);
-
-    tl->freeze();
 }
 
 KSpriteSetup::~KSpriteSetup()
@@ -99,10 +128,9 @@ KSpriteSetup::~KSpriteSetup()
 // read settings from config file
 void KSpriteSetup::readSettings()
 {
-    KConfig *config = KGlobal::config();
-    config->setGroup( "Settings" );
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    speed = config->readNumEntry( "Speed", 50 );
+    speed = config.readEntry( "Speed", 50 );
     if (speed > 100)
 	speed = 100;
     else if (speed < 0)
@@ -119,18 +147,17 @@ void KSpriteSetup::slotSpeed(int s)
 // Ok pressed - save settings and exit
 void KSpriteSetup::slotOkPressed()
 {
-    KConfig *config = KGlobal::config();
-    config->setGroup("Settings");
-    config->writeEntry("Speed", speed);
-    config->sync();
+    KConfigGroup config(KGlobal::config(), "Settings");
+    config.writeEntry("Speed", speed);
+    config.sync();
     accept();
 }
 
 void KSpriteSetup::slotAbout()
 {
-  QMessageBox::message(i18n("About KTux"),
+  KMessageBox::information(this,
     i18n("KTux Version 1.0\n\nWritten by Martin R. Jones 1999\nmjones@kde.org"),
-    i18n("OK"));
+    i18n("About KTux"));
 }
 
 
@@ -138,14 +165,15 @@ void KSpriteSetup::slotAbout()
 
 KSpriteSaver::KSpriteSaver( WId id ) : KScreenSaver( id )
 {
-    KGlobal::dirs()->addResourceType("sprite", KStandardDirs::kde_default("data") + "ktux/sprites/");
+    KGlobal::dirs()->addResourceType("sprite", "data", "ktux/sprites/");
 
     initialise();
     readSettings();
     blank();
 
     connect(&mTimer, SIGNAL(timeout()), SLOT(slotTimeout()));
-    mTimer.start(120-mSpeed, true);
+    mTimer.setSingleShot(true);
+    mTimer.start(120-mSpeed);
 }
 
 //-----------------------------------------------------------------------------
@@ -161,7 +189,7 @@ KSpriteSaver::~KSpriteSaver()
 void KSpriteSaver::setSpeed(int speed)
 {
     mSpeed = speed;
-    mTimer.changeInterval(120-mSpeed);
+    mTimer.start(120-mSpeed);
 }
 
 //-----------------------------------------------------------------------------
@@ -171,10 +199,9 @@ void KSpriteSaver::readSettings()
 {
     QString str;
 
-    KConfig *config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    mSpeed = config->readNumEntry("Speed", 50);
+    mSpeed = config.readEntry("Speed", 50);
 
     QString path = KGlobal::dirs()->findResourceDir( "sprite", "bg.png" );
 
@@ -182,35 +209,39 @@ void KSpriteSaver::readSettings()
 
     path += "spriterc";
 
-    KSimpleConfig *mConfig = new KSimpleConfig(path, true);
-    mConfig->setGroup("Config");
-    QStrList list;
-    int groups = mConfig->readListEntry("Groups", list);
-    mTimerIds.resize(groups);
-    for (int i = 0; i < groups; i++)
+    KConfig *pConfig = new KConfig(path);
+    KConfigGroup mConfig(pConfig, "Config");
+    QStringList list;
+    list = mConfig.readEntry("Groups",list);
+    mTimerIds.resize(list.count());
+    for (int i = 0; i < list.count(); i++)
     {
-	kdDebug() << "Group: " << list.at(i) << endl;;
-	mConfig->setGroup(list.at(i));
-	SpriteGroup *obj = new SpriteGroup(mCanvas, *mConfig);
+	kDebug() << "Group: " << list.at(i);
+        KConfigGroup grp = pConfig->group(list.at(i));
+	SpriteGroup *obj = new SpriteGroup(mCanvas, grp);
 	mTimerIds[i] = startTimer(obj->refreshTime());
 	mGroups.append(obj);
     }
-    delete mConfig;
+    delete pConfig;
 }
 
 //-----------------------------------------------------------------------------
 void KSpriteSaver::initialise()
 {
-    mCanvas = new QCanvas();
-    QPixmap pm( locate("sprite", "bg.png") );
+    mCanvas = new Q3Canvas();
+    QPixmap pm( KStandardDirs::locate("sprite", "bg.png") );
     mCanvas->setBackgroundPixmap( pm );
     mCanvas->resize( width(), height() );
-    mView = new QCanvasView(mCanvas);
-    mView->viewport()->setBackgroundColor( black );
+    mView = new Q3CanvasView(mCanvas);
+
+    QPalette palette;
+    palette.setColor(mView->viewport()->backgroundRole(), Qt::black);
+    mView->viewport()->setPalette(palette);
+
     mView->resize( size());
     mView->setFrameStyle( QFrame::NoFrame );
-    mView->setVScrollBarMode( QScrollView::AlwaysOff );
-    mView->setHScrollBarMode( QScrollView::AlwaysOff );
+    mView->setVScrollBarMode( Q3ScrollView::AlwaysOff );
+    mView->setHScrollBarMode( Q3ScrollView::AlwaysOff );
     embed( mView );
     mView->show();
     SpriteRange::setFieldSize(mView->size());
@@ -219,10 +250,11 @@ void KSpriteSaver::initialise()
 //-----------------------------------------------------------------------------
 void KSpriteSaver::slotTimeout()
 {
-    mTimer.start(120-mSpeed, true);
+    mTimer.setSingleShot(true);
+    mTimer.start(120-mSpeed);
     SpriteGroup *grp;
 
-    for (grp = mGroups.first(); grp; grp = mGroups.next())
+	Q_FOREACH( grp, mGroups )
     {
 	grp->next();
     }
@@ -233,7 +265,7 @@ void KSpriteSaver::slotTimeout()
 //-----------------------------------------------------------------------------
 void KSpriteSaver::timerEvent(QTimerEvent *ev)
 {
-    for (unsigned i = 0; i < mTimerIds.size(); i++)
+    for (int i = 0; i < mTimerIds.size(); i++)
     {
 	if (mTimerIds[i] == ev->timerId())
 	{
@@ -248,7 +280,10 @@ void KSpriteSaver::timerEvent(QTimerEvent *ev)
 //-----------------------------------------------------------------------------
 void KSpriteSaver::blank()
 {
-    setBackgroundColor( black );
-    erase();
+    QPalette palette;
+    palette.setColor(this->backgroundRole(), Qt::black);
+    this->setPalette(palette);
+
+    update();
 }
 
